@@ -1,8 +1,8 @@
 from loguru import logger
 from argparse import ArgumentParser
 
-from ransack import bugs
-from ransack.utils import get_id, Settings
+from rsack import bugs
+from rsack.utils import get_id, Settings
 
 def get_args():
     parser = ArgumentParser()
